millenniums = {
    "тисяча": 1E3,
    "мільйон": 1E6,
    "мільярд": 1E9,
    "трильйон": 1E12,
}

all_num = {
    "тисяча": 1E3,
    "мільйон": 1E6,
    "мільярд": 1E9,
    "трильйон": 1E12,
    "сто": 100,
    "двісті": 200,
    "триста": 300,
    "чотириста": 400,
    "п'ятсот": 500,
    "шістсот": 600,
    "сімсот": 700,
    "вісімсот": 800,
    "дев'ятсот": 900,
    "один": 1,
    "два": 2,
    "три": 3,
    "чотири": 4,
    "п'ять": 5,
    "шість": 6,
    "сім": 7,
    "вісім": 8,
    "дев'ять": 9,
    "десять": 10,
    "одинадцять": 11,
    "дванадцять": 12,
    "тринадцять": 13,
    "чотирнадцять": 14,
    "п'ятнадцять": 15,
    "шістнадцять": 16,
    "сімнадцять": 17,
    "вісімнадцять": 18,
    "дев'ятнадцять": 19,
    "двадцять": 20,
    "тридцять": 30,
    "сорок": 40,
    "п'ятдесят": 50,
    "шістдесят": 60,
    "сімдесят": 70,
    "вісімдесят": 80,
    "дев'яносто": 90,
}
